@@ -41,9 +41,9 @@
 ** Build options, use these to select what you want to include
 ** in the Name Service Switch handler.
 */
-#define ENABLE_YP 	1		/* NSSwitch YP support   */
-#define ENABLE_NIS	1		/* NSSwitch NIS+ support */
-
+#define ENABLE_YP 	1		/* NSSwitch YP (NIS v2) support   */
+#define ENABLE_NIS	1		/* NSSwitch NIS+ (NIS v3) support */
+#define ENABLE_DNS      1		/* NSSwitch DNS/Hesiod support    */
 
 /*
 ** Low level support options, use these to enable emulation code
