@@ -51,4 +51,12 @@ extern void endnswent(void);
 extern struct nsw *getnswent(void);
 extern struct nsw *getnswbyname(char *name);
 
+
+
+#ifdef FINALOUT
+#  define _ENSWF(fname) fname
+#else
+#  define _ENSWF(fname) nsw ## fname
+#endif
+
 #endif
