@@ -29,10 +29,22 @@
 #include <sys/types.h>
 #include <pwd.h>
 
-void nsw_setpwent(void);
-void nsw_endpwent(void);
-struct passwd *nsw_getpwent(void);
-struct passwd *nsw_getpwuid(uid_t uid);
-struct passwd *nsw_getpwnam(char *name);
+#ifdef ENABLE_NIS
+#include "../../nis/src/nis_passwd.h"
+#endif
+
+#ifdef ENABLE_YP
+#include "../../yp/src/yp_passwd.h"
+#endif
+
+#ifdef ENABLE_DNS
+#include "../../dns/src/dns_passwd.h"
+#endif
+
+void _ENSWF(_setpwent)(void);
+void _ENSWF(_endpwent)(void);
+struct passwd * _ENSWF(_getpwent)(void);
+struct passwd * _ENSWF(_getpwuid)(uid_t uid);
+struct passwd * _ENSWF(_getpwnam)(char *name);
 
 #endif
