@@ -28,7 +28,7 @@
 
 extern char *_yp_xcopy(char **cp, char *str);
 extern char *_yp_xstrtok(char *cp, int delim);
-extern char *_ypopts_getmd(char *opts,
+extern char *_ypopts_getmd(void *opts,
 			   char *defmap,
 			   char *suffix,
 			   char **domain);
