@@ -66,7 +66,7 @@ static char *savekey = NULL;
 static int savekeylen = 0;
 
 
-void yp_setpwent(char *opts)
+void yp_setpwent(void *opts)
 {
     rewind_flag = 1;
     if (savekey)
@@ -74,7 +74,7 @@ void yp_setpwent(char *opts)
 }
 
 
-void yp_endpwent(char *opts)
+void yp_endpwent(void *opts)
 {
     rewind_flag = 1;
     if (savekey)
@@ -82,7 +82,7 @@ void yp_endpwent(char *opts)
 }
 
 
-struct passwd *yp_getpwent(char *opts)
+struct passwd *yp_getpwent(void *opts)
 {
     struct passwd *pw;
     char *map;
@@ -133,7 +133,7 @@ struct passwd *yp_getpwent(char *opts)
 }
 
 
-struct passwd *yp_getpwuid(uid_t uid, char *opts)
+struct passwd *yp_getpwuid(uid_t uid, void *opts)
 {
     struct passwd *pw;
     char *map;
@@ -164,7 +164,7 @@ struct passwd *yp_getpwuid(uid_t uid, char *opts)
 }
 
 
-struct passwd *yp_getpwnam(char *name, char *opts)
+struct passwd *yp_getpwnam(char *name, void *opts)
 {
     struct passwd *pw;
     char *map;
