@@ -32,12 +32,12 @@ main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    yp_setpwent();
+    yp_setpwent(NULL);
 
-    while (pw = yp_getpwent())
+    while (pw = yp_getpwent(NULL))
 	print_passwd(pw);
 
-    yp_endpwent();
+    yp_endpwent(NULL);
     
     exit(0);
 }
